%% BASELINE CALIBRATION VALUES FOR NK MODEL


%% model parameters
% policy weights
% alpha_x  = 1; %#ok<NASGU>

% stochastic processes
% rho      = .9;
% sig_eta  = 1;
% sig_e    = 1;
% sig_eps  = 1;
% rho_b    = 0;
% sig_b    = 1; % sqrt(sig_eta^2 / (1-rho^2) + sig_e^2);


% preferences
beta    = .99;
phi     = 1;   % inverse Frisch labor elasticity
sigma   = 1;   % Risk-Aversion / Inverse IES

% Philipps Curve
theta   = .75;    % Calvo Probability of *not* resetting price
kappa   = (1 - theta) * (1 - beta * theta) / theta * (sigma + phi); % lambda  = (1 - theta) * (1 - beta * theta) / theta;

% indexation rate (price setting)
% gamma   = 1;

% Markup
mu      = .5;  % steady state markup
nu      = -mu; % subsidy, offsetting markup

%% some parameters for sticky wages/prices model
% allowing also for decreasing returns to labor 
% (Gali, chapter 6)
% Note: baseline calibration of the Gali book is slightly different from the World Congress Paper

alphaCapitalShare       = 2/3;    % alphaCapitalShare = 0 makes production linear in labor $$Y(i)_t = A_t x N(i)_t^(1-\alphaCapitalShare)$$
                      % otherwise, alphaCapitalShare = 2/3 would be conventional

eval(string4ini('theta_p', 2/3)) % 3/4 in WC paper                      
eval(string4ini('theta_w', 3/4))                      

epsilon_p   = 6;    % 11 in WC paper
epsilon_w   = 6;    % this value is not reported in Gali's Book, as in EHL I use the same as for epsilonP. EHL use a value of 4 (corresponding to their theta_w = 1/3; epsilon_w = (1 + theta_w) / theta_w ).

lambda_p    = (1 - theta_p) * (1 - beta * theta_p) / theta_p * (1 - alphaCapitalShare) / (1 - alphaCapitalShare + alphaCapitalShare * epsilon_p);
lambda_w    = (1 - theta_w) * (1 - beta * theta_w) / theta_w / (1 + epsilon_w * phi);

kappa_p     = alphaCapitalShare / (1 - alphaCapitalShare) * lambda_p;
kappa_w     = lambda_w * (sigma + phi / (1 - alphaCapitalShare));

% natural rate coefficients
psi_ya      = (1 + phi) / (sigma * (1 - alphaCapitalShare) + phi + alphaCapitalShare);
psi_wa      = (1 - alphaCapitalShare * psi_ya) / (1 - alphaCapitalShare);

% microfounded welfare weights
alpha_x     = sigma + (phi + alphaCapitalShare) / (1 - alphaCapitalShare);
alpha_p     = epsilon_p / lambda_p;
alpha_w     = epsilon_w * (1 - alphaCapitalShare) / lambda_w;
alpha_i     = 0;

% % normalize weights
% SumAlphas = alpha_x + alpha_p + alpha_w + alpha_i;
% alpha_x   = alpha_x / SumAlphas;
% alpha_p   = alpha_p / SumAlphas;
% alpha_w   = alpha_w / SumAlphas;
% alpha_i   = alpha_i / SumAlphas;

%% Talyor Rule 
phi_i    = 0;
phi_pi   = 2.5;
phi_x    = 0.5;
