function abcd = abcdIRF(abcd, lags, X0, X0name)
% ABCDIRF generates impulse responses for ABCD state space systems
% USAGE: 
% - abcd = abcdIRF(abcd, lags) generates lags impulse responses to unit white noise shocks
% - abcd = abcdIRF(abcd, lags, X0) additionally generates the dynamics resulting from initial condition X0 w/o further shocks
%   the timing for X0 is as follows: X(-1) = X0 !

%   Coded by  Elmar Mertens, em@elmarmertens.com

error(nargchk(1,4,nargin))

if nargin < 2 || isempty(lags)
   lags = 40;
end
if nargin < 3
   X0 = [];
end
if nargin < 4
   X0name = [];
end


if isempty(X0)
   nirf = abcd.Nw;
else
   nirf = abcd.Nw + 1;
   if isfield(abcd, 'Wnames')
      if isempty(X0name)
         abcd.IMPnames = cat(2, abcd.Wnames, 'X_0');
      else
         abcd.IMPnames = cat(2, abcd.Wnames, X0name);
      end
   end
end

IRFx      = zeros([abcd.Nx nirf lags + 1]);
IRFy      = zeros([abcd.Ny nirf lags + 1]);

IRFx(:,1:abcd.Nw,1) = abcd.B;
IRFy(:,1:abcd.Nw,1) = abcd.D;

if ~isempty(X0)
   IRFx(:,end,1) = abcd.A * X0;
   IRFy(:,end,1) = abcd.C * X0;
end

for k = 1 : lags
   IRFx(:,:,k+1) = abcd.A * IRFx(:,:,k);
   IRFy(:,:,k+1) = abcd.C * IRFx(:,:,k);
end

abcd.IRFx = choppy(IRFx);
abcd.IRFy = choppy(IRFy);


