function abcd = abcdmoments(abcd, lags)
% function abcd = abcdmoments(abcd, lags)
% mean and VCV of state space 
% if lags > 0: GammaY and GammaX will return ACF up to lag'th lag
% [default: lag = 0]
%
% X_{t+1} = A X_t + B w_t
% Y_t     = C X_t + D w_t
% X is allowed to contain a constant

%   Coded by  Elmar Mertens, em@elmarmertens.com

error(nargchk(1,2,nargin))

if nargin < 2 || isempty(lags)
   lags = 0;
end

% read out dimensions of State Space
abcd.Ny           = size(abcd.C, 1);
[abcd.Nx abcd.Nw] = size(abcd.B);

% First Moments
[evc, eva]  = eig(abcd.A);
und = diag(eva) == 1;
switch sum(und)
   case 0   
      abcd.EX  = zeros(length(abcd.A), 1);
   case 1
      abcd.EX  = evc(:, und) / evc(und, und);
   otherwise
      error('multiple constants in state space')
end
abcd.EY     = abcd.C * abcd.EX;

% Second Moments
% abcd.GammaX         = NaN([abcd.Nx abcd.Nx lags+1]);
% abcd.GammaY         = NaN([abcd.Ny abcd.Ny lags+1]);
abcd.GammaX         = zeros([abcd.Nx abcd.Nx lags+1]);
abcd.GammaY         = zeros([abcd.Ny abcd.Ny lags+1]);

abcd.GammaX(:,:,1)   = dlyapdoubling(abcd.A, abcd.B * abcd.B');  % Variance of X
abcd.GammaY(:,:,1)   = abcd.C * abcd.GammaX(:,:,1) * abcd.C' + abcd.D * abcd.D';
Apowerklag           = eye(size(abcd.A));
for k = 1 : lags
   abcd.GammaX(:,:,k+1) = abcd.A * abcd.GammaX(:,:,k);
   abcd.GammaY(:,:,k+1) = abcd.C * abcd.GammaX(:,:,k+1) * abcd.C' + ...
      abcd.C * Apowerklag * abcd.B * abcd.D';
   Apowerklag           = abcd.A * Apowerklag;
end

