function [ftilde, fhat, kappatilde, gtilde, ghat, ELOSS, q, l, c] = burgundy101rootsolve(R2, alpha_x, alpha_p, kappa, beta, rho)
% BURGUNDY101ROOTSOLVE ...
%
%   ...

%% VERSION INFO
% AUTHOR    : Elmar Mertens
% $DATE     : 21-Oct-2014 10:59:04 $
% $Revision : 1.00 $
% DEVELOPED : 8.1.0.604 (R2013a)
% FILENAME  : burgundy101rootsolve.m


betarho = beta * rho;

% setup polynomial in phi
psi_x = (1 - betarho)^2 * alpha_x;
psi_p = alpha_p * kappa^2;
c = psi_x + psi_p * (1 - betarho)^2;
q = psi_p * (betarho * R2) * (1 - betarho * R2);
l = psi_x + psi_p * (1 - betarho) * (1 - 2 * betarho * R2);
phieq = roots([q l -c]);
% pick the right solution
phi = max(phieq);
if phi < 0 || (phi - 1 > 1e-6)
    error houston
end


% compute the rest
R2bar = R2 * phi;
kappatilde =  kappa * (1 - betarho * (1 - R2bar)) / (1 - betarho);

ftilde = alpha_x / (alpha_x + alpha_p * kappatilde^2);
fhat   = phi * ftilde;

gtilde = kappatilde * ftilde;
ghat   = kappa / (1 - betarho) * fhat;

ELOSStilde  = alpha_p / alpha_x * (alpha_x + alpha_p * kappatilde^2) * gtilde^2;
checkdiff(ELOSStilde, alpha_x * alpha_p * kappatilde^2 / (alpha_x + alpha_p * kappatilde^2));

ELOSS  = ELOSStilde + rho^2 / (1 - rho^2) * R2 * alpha_p / alpha_x * (alpha_x + alpha_p * kappatilde^2) * ghat^2;

