%% execute burgundy models

initscript
wrap = []; 
% wrap = 'images';
% note: to store figures as pdf, set wrap to name of target directory
% (use 'pwd' functions or '.' for current directory)
% no figures will be stored if wrap is set to empty

irflags = 12;

%% setup model
baselinecalibration
setup201static
irfndx      = 1 : 2;
beliefndx   = [3 4];

%% For comparison: CE Markov solutions
[fip, Fbar, Gbar] = markovfullinfopolicyi(randn(nu, nx), randn(ny, nx), beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, xNames, yNames, uNames, wNames);

fip = abcdIRF(fip, irflags);


%% solve burgundy
F0 = [Fbar zeros(size(Fbar))]; % + randn(nu, nx * 2);
G0 = Gbar; % + randn(ny, nx);

[hip, pip, F, G, G0, converged, history, iter] = ...
    burgundypolicyi(F0, G0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames);

if ~converged
    error('no convergence')
end

hip         = abcdIRF(hip, irflags);

%% some output
hrulefill
display(F)
display(G)
display(iter)
hrulefill


%% compare results
tol = 1e-8;
shockvarsum = (sig_gamma^2 + sig_eps^2);
R2 = sig_gamma^2 / (sig_gamma^2 + sig_eps^2); 
[ftilde, fhat, kappatilde, gtilde, ghat, ELOSS,q , l, c] = burgundy101rootsolve(R2, alpha_x, alpha_p, kappa, beta, rho);
checkdiff(ftilde, F(1), tol);
checkdiff(ftilde, F(2), tol);
checkdiff(fhat, F(1)+F(3), tol);

checkdiff(gtilde, G(1), tol);
checkdiff(gtilde, G(2), tol);
checkdiff(ghat, G(1)+G(3), tol);

checkdiff(hip.EW / shockvarsum, ELOSS, tol);

inflationvariance = gtilde^2 + rho^2 / (1-rho^2) * R2 * ghat^2;
check             = G(1:3) * hip.Exx(1:3,1:3) * G(1:3)';
checkdiff(inflationvariance, check / shockvarsum, tol);

figure
xgrid = -3 : .01 : 3;
hold on
plot(xgrid, q * xgrid.^2, 'b-', 'linewidth', 2)
plot(xgrid, c - l * xgrid, 'r-', 'linewidth', 2)
plotvertline(1, [], 'k:')
set(gca, 'ytick', [])
plotOrigin
wrapcf('polynomrootsBaseline101', wrap);

% alternative case (with negative root inside unit circle)
alpha_x = .1;
alpha_p = .9;
[ftilde, fhat, kappatilde, gtilde, ghat, ELOSS,q , l, c] = burgundy101rootsolve(R2, alpha_x, alpha_p, kappa, beta, rho);
figure
xgrid = -1 : .01 : 1;
hold on
plot(xgrid, q * xgrid.^2, 'b-', 'linewidth', 2)
plot(xgrid, c - l * xgrid, 'r-', 'linewidth', 2)
% plotvertline(1, [], 'k:')
set(gca, 'ytick', [])
plotOrigin
wrapcf('polynomrootsAlternative101', wrap);



