%% burgundy 201
% surfaces for different parameters
% varying weight Omega of epsilon and tau in variance of output target

initscript

if isdesktop
    quicky = true;
else
    quicky = false;
    wrap = 'images';
    diary off
end

tol = 1e-5;

tolerance   = 1e-8;
maxiter     = 1e3;

warning off control:InaccurateResult


%% settings

if quicky
    ALPHAS      = 0.1 : .1 : .9;
    OMEGAS      = 0   : .1 : 1;
else
    ALPHAS      = .05 : .01 : .99;
    OMEGAS      = 0   : .01 : 1;
end

FIP.Fgamma = NaN(length(ALPHAS),length(OMEGAS));
FIP.Feps = NaN(length(ALPHAS),length(OMEGAS));
FIP.Fhat = NaN(length(ALPHAS),length(OMEGAS));
FIP.Fb   = NaN(length(ALPHAS),length(OMEGAS));

FIP.Ggamma = NaN(length(ALPHAS),length(OMEGAS));
FIP.Geps = NaN(length(ALPHAS),length(OMEGAS));
FIP.Ghat = NaN(length(ALPHAS),length(OMEGAS));
FIP.Gb   = NaN(length(ALPHAS),length(OMEGAS));

FIP.ELOSS = NaN(length(ALPHAS),length(OMEGAS));
FIP.R2    = NaN(length(ALPHAS),length(OMEGAS));
FIP.R2hat = NaN(length(ALPHAS),length(OMEGAS));
FIP.varinf = NaN(length(ALPHAS),length(OMEGAS));

HIP101 = FIP;
HIP    = FIP;


for andx = 1 : length(ALPHAS)
    alpha_x  = ALPHAS(andx);
    alpha_p  = 1 - alpha_x;
    
    for wndx = 1 : length(OMEGAS)
        
        
        
        omega    = OMEGAS(wndx);
        
        %% benchmark values
        
        % stochastic processes
        rho      = .9;
        
        sig_e    = (1 - omega); % omega is R2 for shocks
        sig_eta  = omega;
        
        % preferences
        beta    = .99;
        phi     = 1;   % inverse Frisch labor elasticity
        sigma   = 1;   % Risk-Aversion / Inverse IES
        
        % Philipps Curve
        theta   = .75;    % Calvo Probability of *not* resetting price
        kappa   = (1 - theta) * (1 - beta * theta) / theta * (sigma + phi); % lambda  = (1 - theta) * (1 - beta * theta) / theta;
        
        
        %% setup model matrices
        xNames = {'\gamma', '\epsilon'};
        yNames = {'\pi'};
        uNames = {'x'};
        zNames = {'x'};
        wNames = xNames;
        
        nx = length(xNames);
        ny = length(yNames);
        nu = length(uNames);
        nz = length(zNames);
        nw = length(wNames);
        
        Ix = eye(nx);
        % Iz = eye(nz);
        
        % Loss
        Qxx   = alpha_x * ones(2);
        Qxy   = [0; 0];
        Qyy   = alpha_p;
        Nx    = -alpha_x * ones(2,1);
        Ny    = 0;
        R     = alpha_x;
        
        % x-cons
        Axx   = [rho   0
            0     0
            ];
        Axy   = zeros(nx,ny);
        Bx    = zeros(nx,nu);
        D     = diag([sig_eta, sig_e]);
        
        % y-cons
        Ayy0  = beta;
        Ayy   = 1;
        Ayx   = zeros(ny, nx);
        By    = -kappa;
        
        % Z-cons
        Cx    = zeros(nz, nx);
        Cu    = 1;
        
        %% start values: CE Markov solutions
        [fip, Fbar, Gbar] = markovfullinfopolicyi(randn(nu, nx), randn(ny, nx), beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, xNames, yNames, uNames, wNames);
        fip = abcdmoments(fip, 0);
        
        
        FIP.Fgamma(andx, wndx) = Fbar(1);
        FIP.Feps(andx, wndx)   = Fbar(2);
        FIP.Fhat(andx, wndx)   = Fbar(1);
        FIP.Fb(andx, wndx)     = 0;
        
        FIP.Ggamma(andx, wndx) = Gbar(1);
        FIP.Geps(andx, wndx)   = Gbar(2);
        FIP.Ghat(andx, wndx)   = Gbar(1);
        FIP.Gb(andx, wndx)     = 0;
        
        FIP.ELOSS(andx, wndx)   = fip.EW;
        FIP.varinf(andx, wndx)  = fip.GammaY(2,2);
        
        %% 101 burgundy
        [HIP101.Fgamma(andx,wndx), HIP101.Fhat(andx,wndx), ~, HIP101.Ggamma(andx,wndx), HIP101.Ghat(andx,wndx), HIP101.ELOSS(andx,wndx)] = burgundy101rootsolve(omega, alpha_x, alpha_p, kappa, beta, rho);
        HIP101.Feps(andx,wndx) = HIP101.Fgamma(andx,wndx);
        HIP101.Fb(andx,wndx)   = HIP101.Fhat(andx,wndx) - HIP101.Fgamma(andx,wndx);
        HIP101.Geps(andx,wndx) = HIP101.Ggamma(andx,wndx);
        HIP101.Gb(andx,wndx)   = HIP101.Ghat(andx,wndx) - HIP101.Ggamma(andx,wndx);
        HIP101.R2(andx,wndx)   = omega;
        HIP101.R2hat(andx,wndx) = omega * HIP101.Fgamma(andx,wndx) / HIP101.Fhat(andx,wndx);
        
        %% 201 burgundy
        
        F0 = [Fbar zeros(size(Fbar))];
        G0 = Gbar;
        try
            [hip, pip, F, G, G0, converged, history, iter] = ...
                burgundypolicyi(F0, G0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames, [], tolerance, maxiter);
        catch %#ok<CTCH>
            error houston
        end
        if any(isnan(F(:)))
            error houston
        end
        hip = abcdmoments(hip, 0);
        
        HIP.Fgamma(andx, wndx) = F(1);
        HIP.Feps(andx, wndx)   = F(2);
        HIP.Fhat(andx, wndx)   = F(1) + F(3);
        HIP.Fb(andx, wndx)     = F(3);
        
        HIP.Ggamma(andx, wndx) = G(1);
        HIP.Geps(andx, wndx)   = G(2);
        HIP.Ghat(andx, wndx)   = G(1) + G(3);
        HIP.Gb(andx, wndx)     = G(3);
        
        HIP.ELOSS(andx, wndx)   = hip.EW;
        HIP.varinf(andx, wndx)  = hip.GammaY(2,2);
        
        HIP.R2(andx, wndx)      = hip.K(1) * F(1);
        HIP.R2hat(andx, wndx)   = hip.K(1) * (F(1) + F(3));
        
        
    end
end


%% Figure 2: Output Gap coeffcients (Dynamic case)

% Fgamma
compare3DsurfacesBW(HIP.Fgamma, FIP.Fgamma, 'HI', 'FI', OMEGAS, ALPHAS)
view(30,6)
wrapcf('Fgammabw', wrap)

% Feps
compare3DsurfacesBW(HIP.Feps, FIP.Feps, 'HI', 'FI', OMEGAS, ALPHAS)
view(30,6)
wrapcf('Fepsbw', wrap)

% Fhat
compare3DsurfacesBW(HIP.Fhat, FIP.Fhat, 'HI', 'FI', OMEGAS, ALPHAS)
view(64,10)
wrapcf('Fhatbw', wrap)


%% Figure 2: Output Gap coeffcient (Static case)
% Fgamma
compare3DsurfacesBW(HIP101.Fgamma, FIP.Fgamma, 'HI', 'FI', OMEGAS, ALPHAS)
view(30,6)
wrapcf('Fgamma101bw', wrap)

% Feps
compare3DsurfacesBW(HIP101.Feps, FIP.Feps, 'HI', 'FI', OMEGAS, ALPHAS)
view(30,6)
wrapcf('Feps101bw', wrap)

% Fhat
compare3DsurfacesBW(HIP101.Fhat, FIP.Fhat, 'HI', 'FI', OMEGAS, ALPHAS)
view(64,10)
wrapcf('Fhat101bw', wrap)


%% Figure 3: Inflation coeffcient (Dynamic case)

% Ggamma
compare3DsurfacesBW(HIP.Ggamma, FIP.Ggamma, 'HI', 'FI', OMEGAS, ALPHAS)
view(56,10)
wrapcf('Ggammabw', wrap)

% Geps
compare3DsurfacesBW(HIP.Geps, FIP.Geps, 'HI', 'FI', OMEGAS, ALPHAS)
view(44,40)
wrapcf('Gepsbw', wrap)

% Ghat
compare3DsurfacesBW(HIP.Ghat, FIP.Ghat, 'HI', 'FI', OMEGAS, ALPHAS)
view(64,10)
wrapcf('Ghatbw', wrap)


%% Figure 3: Inflation coeffcient (Static case)

% Ggamma
compare3DsurfacesBW(HIP101.Ggamma, FIP.Ggamma, 'HI', 'FI', OMEGAS, ALPHAS)
view(30,6)
wrapcf('Ggamma101bw', wrap)

% Geps
compare3DsurfacesBW(HIP101.Geps, FIP.Geps, 'HI', 'FI', OMEGAS, ALPHAS)
view(30,6)
wrapcf('Geps101bw', wrap)

% Ghat
compare3DsurfacesBW(HIP101.Ghat, FIP.Ghat, 'HI', 'FI', OMEGAS, ALPHAS)
view(64,10)
wrapcf('Ghat101bw', wrap)


%% FIGURE 4: Comparison of Losses
surface3DBW(FIP.ELOSS -  HIP.ELOSS, OMEGAS, ALPHAS)
view(-40,16)
wrapcf('deltaLoss', wrap)

surface3DBW(FIP.ELOSS -  HIP101.ELOSS, OMEGAS, ALPHAS)
view(-40,16)
wrapcf('deltaLoss101', wrap)


%% FIGURE 5
surface3DBW(bsxfun(@minus, HIP.R2, OMEGAS), OMEGAS, ALPHAS)
view(-30,10)
wrapcf('diffR2ALPHAOMEGA', wrap)


%% wrap up
dockAllFigures
warning on control:InaccurateResult
