initscript
wrap = []; 
% wrap = 'images';
% note: to store figures as pdf, set wrap to name of target directory
% (use 'pwd' functions or '.' for current directory)
% no figures will be stored if wrap is set to empty

%% calibrate model and define matrices


maxiter     = 1e3;
tolerance   = 1e-8;

irflags     = 24;
longlags    = 120;

EHLcalibration

vara = 2;
% varx = 2;
rho_x       = .9;
sig_xtau    = 1;
sig_xnoise  = 1;

gamma = 1;
sig_pibar = -.2;
sig_n     = abs(10 * sig_pibar);

% dual Mandate
alpha_x = 1;
alpha_p = 1;
alpha_w = 0;

GAMMA = .05 : .05 : 1;
setupEHLapxIntNDXnow
beliefndx = 11 :15;
irfndx = [1 7 5 6 4 8];

%% allocate memory
V0 = zeros(nx * 2);
converged = false;
while ~converged
    try
        F0 = randn(nu, nx * 2);
        G0 = randn(ny, nx);
        [hip, tmp1, tmp2, tmp3, tmp4, converged] = burgundypolicyi(F0, G0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames, [], tolerance, maxiter, false);
    catch emptyME
        warning('burgundypolicyi error: %s', emptyME.message);
    end
end
hip = abcdIRF(hip, irflags);
HIP = repmat(hip, length(GAMMA), 1);


%% loop over gamma

for n = 1 : length(GAMMA)
    
    gamma = GAMMA(n);
    
    Ayx(4,8) = gamma;
    Ayx(5,9) = gamma;
    Ayx(4:5,3) = 1-gamma;
    
    converged = false;
    
    while ~converged
        
        %% discretion: hidden info
        F0 = randn(nu, nx * 2);
        G0 = randn(ny, nx);
        try
            [hip, tmp1, tmp2, tmp3, tmp4, converged] = burgundypolicyi(F0, G0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames, [], tolerance, maxiter, false);
        catch emptyME
        end
        

    end
    hip = abcdIRF(hip, irflags);
    hip.IRFy(:,3,:) = hip.IRFy(:,3,:) / abs(sig_pibar);
    HIP(n) = hip;
end


%% extract IRF (hidden info)
RSP = [8 7 11 5];
for r = 1 : length(RSP)
    rspndx = RSP(r);
    impndx = 3;
    
    irf = cell2mat(arrayfun(@(a) squeeze(a.IRFy(rspndx,impndx,:))', HIP, 'uniformoutput', false));
    
    figure
    surf(0:irflags,GAMMA,irf)
    hold on
    contour3(0:irflags, GAMMA, irf, 15, 'w')
    xlabel('lags')
    ylabel('\gamma')
    shading interp
    colormap pink
    title(hip.Ynames{rspndx})
    if rspndx == 7
        view(250, 30)
    else
        view(140,25)
    end
    
    if rspndx == 8
       zlim([0 .5])
    end
    
    wrapcf(sprintf('EHLgamma%d', r), wrap)
    
end



%% finish
fprintf('Done with model %s.\n', modelname)
dockAllFigures
