initscript
wrap = []; 
% wrap = 'images';
% note: to store figures as pdf, set wrap to name of target directory
% (use 'pwd' functions or '.' for current directory)
% no figures will be stored if wrap is set to empty

%% calibrate model and define matrices


maxiter     = 1e4;
tolerance   = 1e-8;

irflags     = 12;
longlags    = 120;

EHLcalibration

% dual Mandate
alpha_x = 1;
alpha_p = 1;
alpha_w = 0;

% triple Mandata
% alpha_x = 1;
% alpha_p = 1;
% alpha_w = 1;

vara = 2;

rho_x       = .9;
sig_xtau    = 1;
sig_xnoise  = 1;


gamma = 1;
sig_pibar = -.3;
sig_n     = abs(1 * sig_pibar);

SIGMAN = [.1 : .1 : 1, 1.25 : .25 : 2, 2.5 : .5 : 10];
% finer grid:
% SIGMAN = [.01 : .01 : 1.99, 2 : .1 : 10];

setupEHLapxIntNDXnow


%% Full info benchmark
[difip,diF,diG]  = markovfullinfoVFI([], [], beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, xNames, yNames, uNames, wNames);
difip = abcdIRF(difip, irflags);

%% allocate memory
V0 = zeros(nx * 2);
converged = false;
while ~converged
    try
        F0 = randn(nu, nx * 2);
        G0 = randn(ny, nx);
        [hip, tmp1, F, tmp3, tmp4, converged] = burgundypolicyi(F0, G0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames, [], tolerance, maxiter, false);
    catch emptyME
    end
end
hip.F = F;
hip = abcdIRF(hip, irflags);
HIP = repmat(hip, length(SIGMAN), 1);


%% loop over gamma
for n = 1 : length(SIGMAN)
    
    sig_n = SIGMAN(n) * abs(sig_pibar);
    D(6,6) = sig_n;
     
    converged = false;
    
    while ~converged
        %% discretion: hidden info
        F0 = randn(nu, nx * 2);
        G0 = randn(ny, nx);
        try
            [hip, tmp1, F, tmp3, tmp4, converged] = burgundypolicyi(F0, G0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames, [], tolerance, maxiter, false);
        catch emptyME
        end
    end
    hip.F = F;
    hip = abcdIRF(hip, irflags);
    HIP(n) = hip;
    
end


%% get ex ante R2
R2exante = NaN(length(SIGMAN),1);
for n = 1 : length(SIGMAN)
    kall.A     = [1 0; 0 0];
    kall.B     = diag([sig_pibar, SIGMAN(n)]);
    kall.C     = [1 1];
    [sig, tmp1, tmp2, sigstar] = abckalman(kall.A, kall.B, kall.C);
    R2exante(n) = 1 - sigstar(1) / sig(1);
end

%% Polar case IRF
irfLO = HIP(end);
irfMI = HIP(find(R2exante > .1, 1, 'last'));
irfHI = HIP(1);

irfLO.IRFy(:,3,:) = irfLO.IRFy(:,3,:) / abs(sig_pibar);
irfMI.IRFy(:,3,:) = irfMI.IRFy(:,3,:) / abs(sig_pibar);
irfHI.IRFy(:,3,:) = irfHI.IRFy(:,3,:) / abs(sig_pibar);

irfLO.IRFy(:,6,:) = irfLO.IRFy(:,6,:)  / (SIGMAN(end) * abs(sig_pibar));
irfHI.IRFy(:,6,:) = irfHI.IRFy(:,6,:)  / (SIGMAN(1) * abs(sig_pibar));
irfMI.IRFy(:,6,:) = irfMI.IRFy(:,6,:)  / (SIGMAN(1) * abs(sig_pibar));

irfndx = [1 8 11 5 4 7];
figure
for n = 1 : length(irfndx)
    subplot(3,2,n)
    hold on
    plot(0:irflags,squeeze(irfLO.IRFy(irfndx(n),3,1:irflags+1)), 'b-', 'linewidth', 2)
    plot(0:irflags,squeeze(irfHI.IRFy(irfndx(n),3,1:irflags+1)), 'r--', 'linewidth', 2)
    plot(0:irflags,squeeze(irfMI.IRFy(irfndx(n),3,1:irflags+1)), 'Color', [0 .4 0], 'linestyle', '-.', 'linewidth', 1)
    xlim([0 irflags])
    title(irfLO.Ynames{irfndx(n)})
    set(gca, 'xtick', 0 : 2 : irflags)
    if irfndx(n) == 11
        ylim([-1.1 0])
    end
end
subplot(3,2,2), legend('No additional target signal', 'Observable target', 'Noisy target signal')
wrapcf('EHLsigmaIRFpistar', wrap)


%% finish
dockAllFigures
