%% execute burgundy models

initscript
wrap = []; 
% wrap = 'images';
% note: to store figures as pdf, set wrap to name of target directory
% (use 'pwd' functions or '.' for current directory)
% no figures will be stored if wrap is set to empty


irflags = 12;

%% setup model
baselinecalibration
setup201


%% For comparison: CE Markov solutions
[fip, Fbar, Gbar] = markovfullinfopolicyi(randn(nu, nx), randn(ny, nx), beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, xNames, yNames, uNames, wNames);

fip = abcdIRF(fip, irflags);


%% solve burgundy
F0 = [Fbar zeros(size(Fbar))]; % + randn(nu, nx * 2);
G0 = Gbar; % + randn(ny, nx);

[hip, pip, F, G, G0, converged, history, iter] = ...
    burgundypolicyi(F0, G0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames);

if ~converged
    error('no convergence')
end

hip         = abcdIRF(hip, irflags);

%% some output
hrulefill
display(F)
display(G)
display(iter)
hrulefill


% %% state spaces and IRF
% 
% figure
% abcdIRFplot(hip, irflags, irfndx, [], fip);
% wrapcf('burgundy', wrap)
% 
% fipirf = NaN(size(hip.IRFy));
% fipirf(1:fip.Ny,:,:) = fip.IRFy;
% figure
% abcdIRFplot(hip, 8, beliefndx, 1:nw, fipirf);
% wrapcf('burgundyBeliefs', wrap)

%% compute 101 static version
setup201static
irfndx      = 1 : 2;
beliefndx   = [3 4];

F0 = randn(nu, nx * 2);
G0 = randn(ny, nx);

hip101 = ...
    burgundypolicyi(F0, G0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames);

if ~converged
    error('no convergence')
end

hip101         = abcdIRF(hip101, irflags);

%% plot 101 and 201
hanni = NaN(3,1);
figure
subplot(2,2,1)
hold on
hanni(1) = plot(0:irflags, squeeze(fip.IRFy(1,1,1:irflags+1)), 'k-', 'linewidth', 2);
hanni(2) = plot(0:irflags, squeeze(hip101.IRFy(1,1,1:irflags+1)), 'b-.', 'linewidth', 2);
hanni(3) = plot(0:irflags, squeeze(hip.IRFy(1,1,1:irflags+1)), 'r--', 'linewidth', 2);
set(gca, 'xtick', 0 : 4 : 12)
xlim([0 12])
ytickfmt(-.2:.2:1)
ylabel('$\bf x$', 'interpreter', 'latex')
plotOrigin
titletexmath('\gamma')

subplot(2,2,2)
hold on
hanni(1) = plot(0:irflags, squeeze(fip.IRFy(1,2,1:irflags+1)), 'k-', 'linewidth', 2);
hanni(2) = plot(0:irflags, squeeze(hip101.IRFy(1,2,1:irflags+1)), 'b-.', 'linewidth', 2);
hanni(3) = plot(0:irflags, squeeze(hip.IRFy(1,2,1:irflags+1)), 'r--', 'linewidth', 2);
set(gca, 'xtick', 0 : 1 : 4)
xlim([0 4])
ytickfmt(-.2:.2:1)
plotOrigin
% ylabel('$\bf x$', 'interpreter', 'latex')
titletexmath('\epsilon')
legend(hanni, 'Full Info', 'Static Hidden Info', 'Dynamic Hidden Info')


subplot(2,2,3)
hold on
hanni(1) = plot(0:irflags, squeeze(fip.IRFy(2,1,1:irflags+1)), 'k-', 'linewidth', 2);
hanni(2) = plot(0:irflags, squeeze(hip101.IRFy(2,1,1:irflags+1)), 'b-.', 'linewidth', 2);
hanni(3) = plot(0:irflags, squeeze(hip.IRFy(2,1,1:irflags+1)), 'r--', 'linewidth', 2);
set(gca, 'xtick', 0 : 4 : 12)
xlim([0 12])
ytickfmt(-.2:.2:1.4)
ylabel('$\bf \pi$', 'interpreter', 'latex')
plotOrigin
% titletexmath('\gamma')

subplot(2,2,4)
hold on
hanni(1) = plot(0:irflags, squeeze(fip.IRFy(2,2,1:irflags+1)), 'k-', 'linewidth', 2);
hanni(2) = plot(0:irflags, squeeze(hip101.IRFy(2,2,1:irflags+1)), 'b-.', 'linewidth', 2);
hanni(3) = plot(0:irflags, squeeze(hip.IRFy(2,2,1:irflags+1)), 'r--', 'linewidth', 2);
set(gca, 'xtick', 0 : 1 : 4)
xlim([0 4])
ytickfmt(-.2:.2:1.4)
plotOrigin
% ylabel('$\bf x$', 'interpreter', 'latex')
% titletexmath('\epsilon')
wrapcf('IRF201', wrap)

%% finish
dockAllFigures
