%% execute burgundy models

initscript
wrap = []; 
% wrap = 'images';
% note: to store figures as pdf, set wrap to name of target directory
% (use 'pwd' functions or '.' for current directory)
% no figures will be stored if wrap is set to empty


%% set parameters
baselinecalibration

setup201

doTitle = false;

%% For comparison: CE Markov solutions
[fip, Fbar, Gbar] = markovfullinfopolicyi(randn(nu, nx), randn(ny, nx), beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, xNames, yNames, uNames, wNames);

xHatNames  = cellfun(@(x) sprintf('%s_{t|t-1}', x), xNames, 'uniformoutput', false);
uInnoNames = cellfun(@(x) sprintf('%s_{t}-%s_{t|t-1}', x, x), uNames, 'uniformoutput', false);

fip         = abcdIRF(fip);

%% solve burgundy

F0 = [Fbar zeros(size(Fbar))];
G0 = Gbar;

[hip, pip, F, G, G0, converged, history, iter] = ...
    burgundypolicyi(F0, G0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames);


if ~converged
    newfig
    multiplot(squeeze(F0hist(:,:,max(1, floor(iter/2)):end))', '.')
    newfig
    multiplot(squeeze(F0hist(:,:,iter-(10:-1:0)))', '.')
    newfig
    multihist(squeeze(F0hist(:,:,500:end))')
    error('no convergence')
end

hip = abcdIRF(hip);
pip = abcdIRF(pip);

%% some output
F                 %#ok<NOPTS>
G                 %#ok<NOPTS>
iter              %#ok<NOPTS>

hrulefill


%% generate IRF for pip with x-tilde shocks
hipirf         = hip.IRFy;
hipirf         = bsxfun(@rdivide, hipirf, hipirf(1,:,1)); % scale to unit shock in x
pipStates      = hipirf([5 6],:,:);
pipInnovations = hipirf(7,:,:) / sqrt(pip.VarZ);
irflags        = size(hip.IRFy, 3) - 1;
piplags        = 20;
pipirf         = NaN([2 2 irflags + 1 piplags]);

% generate IRF at each point in time

for s = 1 : 2
    t = 1;
    pipirf(:,s,:,t) = pip.IRFy * pipInnovations(1,s,t);
    
    for t = 2 : piplags
        % create IRF to three things: x-inno and belief states (tau and eps)
        joe                  = abcdIRF(pip, irflags-t+1, pipStates(:,s,t));
        joe.IRFy(:,1,:)      = joe.IRFy(:,1,:) * pipInnovations(1,s,t); % scale x-inno
        pipirf(:,s,t:end,t)  = sum(joe.IRFy,2); % adding initial condition to new innovations
    end
end

plotIRFs(pipirf(:,:,1:piplags,1), false, [], [], [], [], pipirf(:,:,1:piplags,2:end), 4);

%% prep IRF
close all
laggy = 0 : piplags;
clrs  = Colors4Plots(2:6);
markers = {'p','s', 'o'};
linetypes = {'--', '-.'};

shockcolor = {'r', 'b'};

updatehandle = repmat(2,nw,2);


%% plot initial IRF
black = [0 0 0];
hanni = NaN(3,1);
for y = 1 : 2
    
    % plot true IRF and updates initial pip
    
    figure
    set(gca, 'fontsize', 12)
    hold on
    
    % true IRF
    for w = 1 : nw
        hanni(1+w) = plot(laggy, squeeze(hipirf(y,w,1:piplags+1)), ...
            shockcolor{w}, 'linestyle', '-', 'linewidth', 3, 'marker', 'd');
    end
    % initial pip IRF (same across shocks)
    t = 1;
    hanni(1) = plot(laggy, squeeze(pipirf(y,1,1:piplags+1,t)), '-', 'color', black, 'linewidth', 3, 'markersize', 8);
    
    plotOrigin
    xlim([0 4])
    set(gca,'xtick', 0 : 6)
    if doTitle
        titletexmath(hip.Ynames{y}) %#ok<*UNRCH>
    end
    h = legend(hanni, sprintf('$\\bf %s_{t|0}$', hip.Ynames{y}), ...
        sprintf('$\\bf E_0(%s_t) \\; after \\; shock \\; to \\; \\gamma_0$', hip.Ynames{y}), ...
        sprintf('$\\bf E_0(%s_t) \\; after \\; shock \\; to \\;  \\epsilon_0$', hip.Ynames{y}));
    set(h, 'interpreter', 'latex')
    
    switch y
        case 1
            ytickfmt(-.5 : .5 : 1);
            
        case 2
            ytickfmt(0 : .2 : 1);
    end
    
    wrapcf(sprintf('burgundy201pipTime0y%d', y), wrap)
    
end % y

%% plot initial IRF -- per SHOCK!
green = [.6 .6 .6];
hanni = NaN(2,1);
% true IRF
for w = 1 : nw
    for y = 1 : 2
        
        % plot true IRF and updates initial pip
        
        figure
        set(gca, 'fontsize', 12)
        hold on
        
        hanni(2) = plot(laggy, squeeze(hipirf(y,w,1:piplags+1)), ...
            shockcolor{w}, 'linestyle', '-', 'linewidth', 3, 'marker', 'd');
        % initial pip IRF (same across shocks)
        t = 1;
        hanni(1) = plot(laggy, squeeze(pipirf(y,1,1:piplags+1,t)), '-', 'color', black, 'linewidth', 3, 'markersize', 8);
        
        plotOrigin
        xlim([0 4])
        set(gca,'xtick', 0 : 6)
        if doTitle
            titletexmath(hip.Ynames{y}) %#ok<*UNRCH>
        end
        h = legend(hanni, sprintf('$\\bf %s_{t|0}$', hip.Ynames{y}), ...
            sprintf('$\\bf E_0(%s_t)$', ...
            hip.Ynames{y}));
        %         h = legend(hanni, sprintf('$\\bf %s_{t|0}$', hip.Ynames{y}), ...
        %             sprintf('$\\bf E_0(%s_t) \\; after \\; shock \\; to \\; %s_0$', ...
        %             hip.Ynames{y}, hip.Wnames{w}));
        set(h, 'interpreter', 'latex')
        
        switch y
            case 1
                ytickfmt(-.5 : .5 : 1);
                
            case 2
                ytickfmt(0 : .2 : 1);
        end
        
        plotvertline(0, [], '-', 'color', green, 'linewidth', 3)
        plothorzline(0, [], '-', 'color', green, 'linewidth', 3)
        wrapcf(sprintf('burgundy201pipTime0y%dw%d', y,w), wrap)
        
    end % y
end % w


%% plot update at t=2
hanni = NaN(3,1);
for y = 1 : 2
    
    % plot true IRF and updates for each shock
    for w = 1 : nw
        
        figure
        set(gca, 'fontsize', 12)
        hold on
        
        % true IRF
        hanni(3) = plot(laggy, squeeze(hipirf(y,w,1:piplags+1)), ...
            shockcolor{w}, 'linestyle', '-', 'linewidth', 3, 'marker', 'd');
        
        % initial pip IRF (same across shocks)
        t = 1;
        hanni(t) = plot(laggy, squeeze(pipirf(y,w,1:piplags+1,t)), '--', 'color', black, 'linewidth', 2, 'markersize', 8);
        t = 2;
        hanni(t) = plot(laggy, squeeze(pipirf(y,w,1:piplags+1,t)), '-', 'color', black, 'linewidth', 3, 'markersize', 8);
        %         t = 3;
        %         plot(laggy, squeeze(pipirf(y,w,1:piplags+1,t)), shockcolor{w}, 'linestyle', '--', 'linewidth', 1, 'markersize', 8);
        
        plotOrigin
        xlim([0 4])
        set(gca,'xtick', 0 : 6)
        if doTitle
            titletexmath(hip.Ynames{y})
        end
        h = legend(hanni, sprintf('$\\bf %s_{t|0}$', hip.Ynames{y}), ...
            sprintf('$\\bf %s_{t|1}$', hip.Ynames{y}),  ...
            sprintf('$\\bf E_0(%s_t)$', hip.Ynames{y}));
        %         h = legend(hanni, sprintf('$\\bf %s_{t|0}$', hip.Ynames{y}), ...
        %             sprintf('$\\bf %s_{t|1}$', hip.Ynames{y}),  ...
        %             sprintf('$\\bf E_0(%s_t) \\; after \\; shock \\; to \\; %s_0$', hip.Ynames{y}, hip.Wnames{w}));
        
        set(h, 'interpreter', 'latex')
        switch y
            case 1
                ytickfmt(-.5 : .5 : 1);
                
            case 2
                ytickfmt(0 : .2 : 1);
        end
        
        plotvertline(1, [], '-', 'color', green,'linewidth', 3)
        plothorzline(0, [], '-', 'color', green, 'linewidth', 3)
        
        wrapcf(sprintf('burgundy201pipTime1y%dw%d', y, w), wrap)
        
    end % w
end % y

%% plot update at t=3
hanni = NaN(4,1);
for y = 1 : 2
    
    % plot true IRF and updates for each shock
    for w = 1 : nw
        
        figure
        set(gca, 'fontsize', 12)
        hold on
        
        % true IRF
        hanni(end) = plot(laggy, squeeze(hipirf(y,w,1:piplags+1)), ...
            shockcolor{w}, 'linestyle', '-', 'linewidth', 3, 'marker', 'd');
        
        % initial pip IRF (same across shocks)
        t = 1;
        hanni(t) = plot(laggy, squeeze(pipirf(y,w,1:piplags+1,t)), '--', 'color', black, 'linewidth', 1, 'markersize', 8);
        t = 2;
        hanni(t) = plot(laggy, squeeze(pipirf(y,w,1:piplags+1,t)), '--', 'color', black, 'linewidth', 2, 'markersize', 8);
        t = 3;
        hanni(t) = plot(laggy, squeeze(pipirf(y,w,1:piplags+1,t)), '-', 'color', black, 'linewidth', 3, 'markersize', 8);
        
        plotOrigin
        xlim([0 4])
        set(gca,'xtick', 0 : 6)
        if doTitle
            titletexmath(hip.Ynames{y})
        end
        h = legend(hanni, sprintf('$\\bf %s_{t|0}$', hip.Ynames{y}), ...
            sprintf('$\\bf %s_{t|1}$', hip.Ynames{y}),  ...
            sprintf('$\\bf %s_{t|2}$', hip.Ynames{y}),  ...
            sprintf('$\\bf E_0(%s_t)$', hip.Ynames{y}));
        set(h, 'interpreter', 'latex')
        
        switch y
            case 1
                ytickfmt(-.5 : .5 : 1);
                
            case 2
                ytickfmt(0 : .2 : 1);
        end

        plotvertline(2, [], '-', 'color', green,'linewidth', 3)
        plothorzline(0, [], '-', 'color', green, 'linewidth', 3)

        wrapcf(sprintf('burgundy201pipTime2y%dw%d', y, w), wrap)
        
    end % w
end % y


%% wrap up
dockAllFigures
