%% execute burgundy models

initscript
wrap = []; 
% wrap = 'images';
% note: to store figures as pdf, set wrap to name of target directory
% (use 'pwd' functions or '.' for current directory)
% no figures will be stored if wrap is set to empty


%% setup model matrices
modelname = '202';

baselinecalibration

rho = .9;
sig_n = 1;
sig_eta = 1;
sig_e   = 1;

xNames = {'\gamma', '\epsilon', 'n'};
yNames = {'\pi'};
uNames = {'x'};
zNames = {'target', 'x'}; 
wNames = xNames;

nx = length(xNames);
ny = length(yNames);
nu = length(uNames);
nz = length(zNames);
nw = length(wNames);

Ix = eye(nx);
% Iz = eye(nz);

% Loss
Qxx   = [alpha_x  alpha_x 0
         alpha_x  alpha_x 0 
         0        0       0]; 
Qxy   = [0; 0; 0];
Qyy   = 1;
Nx    = [-alpha_x;-alpha_x;0];
Ny    = 0;
R     = alpha_x;

% x-cons
Axx   = [rho   0  0
         0     0  0
         0     0  0
        ];
Axy   = zeros(nx,ny);
Bx    = zeros(nx,nu);
D     = diag([sig_eta, sig_e, sig_n]);

% y-cons
Ayy0  = beta;
Ayy   = 1;
Ayx   = zeros(ny, nx);
By    = -kappa;

% Z-cons
Cx    = [1 0 1; 0 0 0];
Cu    = [0; 1];

%% dimension checks
dimchk(Qxx, nx, nx);
dimchk(Qxy, nx, ny);
dimchk(Qyy, ny, ny);
dimchk(Nx, nx, nu);
dimchk(Ny, ny, nu);
dimchk(R, nu, nu);
dimchk(Axx, nx, nx);
dimchk(Axy, nx, ny);
dimchk(Bx, nx, nu);
dimchk(D, nx, nw);
dimchk(Ayy0, ny, ny);
dimchk(Ayy, ny, ny);
dimchk(Ayx, ny, nx);
dimchk(By, ny, nu);
dimchk(Cx, nz, nx);
dimchk(Cu, nz, nu);

% calibrationtable
% calibrationlatextable

klong = 8;
longname = sprintf('i^{%d}', klong);
spreadname = sprintf('%s-i', longname);

irflags = 4;

%% For comparison: CE Markov solutions
[fip, Fbar, Gbar] = markovfullinfopolicyi(randn(nu, nx), randn(ny, nx), beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, xNames, yNames, uNames, wNames);


fip = abcdIRF(fip);

% newfig
% abcdIRFplot(fip, irflags);
% wrapcf('burgundyfip', wrap)

%% solve burgundy
F0 = [Fbar zeros(size(Fbar))]; % + randn(nu, nx * 2);
G0 = Gbar; % + randn(ny, nx);

% [hip, pip, converged, F, G, V, v, EV, K, Sigma, SigmaStar, Ctilde, R2, iter, F0hist] = ...
%     burgundypolicyiHATTRICK(F0, G0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames);

[hip, pip, F, G, G0, converged, history, iter] = ...
    burgundypolicyi(F0, G0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames);

if ~converged
    newfig
    multiplot(squeeze(F0hist(:,:,max(1, floor(iter/2)):end))', '.')
    newfig
    multiplot(squeeze(F0hist(:,:,iter-(10:-1:0)))', '.')
    newfig
    multihist(squeeze(F0hist(:,:,500:end))')
    error('no convergence')
end

%% some output
F                 %#ok<NOPTS>
G                 %#ok<NOPTS>
% EV                %#ok<NOPTS>
% K                 %#ok<NOPTS>
% Sigma             %#ok<NOPTS>
% SigmaStar         %#ok<NOPTS>
iter              %#ok<NOPTS>

hrulefill

%% compute IRF
x0          = zeros(nx * 2, 1);
x0(nx + 1)  = 1;% x0(nx + 1)  = 1;
hip         = abcdIRF(hip, [], x0, '\gamma_{t|t-1}');

%% hiphat system
hiphat.A    = hip.A;
hiphat.B    = hip.B;
hiphat.Cx   = [zeros(hip.Ny, nx) hip.Cx(:,1:nx)+hip.Cx(:,1+nx:end)];
hiphat.Ynames = strcat(hip.Ynames, '_{t|t-1}');
hiphat.Xnames = hip.Xnames;
hiphat.Wnames = hip.Wnames;
hiphat      = abcddims(hiphat);
hiphat      = abcdIRF(hiphat, [], x0);
% hiphat.IRFy(:,:,1) = NaN;

%% state spaces and IRF

laggy = 1:irflags+1;
close all

% fullscreen = get(0,'ScreenSize');
% figure('Position',[0 -50 fullscreen(3) fullscreen(4)])

figure
subplot(2,3,1)
set(gca, 'fontsize', 16)
hold on
plot(laggy-1, squeeze(hip.IRFy(1,3,laggy)), 'linewidth', 2)
plot(laggy-1, squeeze(hiphat.IRFy(1,3,laggy)), 'r--', 'linewidth', 2)
plot(xlim, [0 0], 'k:', 'linewidth', .5)
set(gca, 'xtick', 0 : irflags)
xlim([0 irflags])
ytikka = -.2 : .1 : .2;
set(gca, 'ytick', ytikka)
set(gca, 'yticklabel', sprintf('%2.1f|', ytikka))
title('$\bf x_t$', 'interpreter', 'latex')
h = legend('$\bf x_t$', '$\bf x_{t|t-1}$');
set(h, 'interpreter', 'latex')



subplot(2,3,2)
set(gca, 'fontsize', 16)
hold on
plot(laggy-1, squeeze(hip.IRFy(2,3,laggy)), 'linewidth', 2)
plot(laggy-1, squeeze(hiphat.IRFy(2,3,laggy)), 'r--', 'linewidth', 2)
plot(xlim, [0 0], 'k:', 'linewidth', .5)
set(gca, 'xtick', 0 : irflags)
xlim([0 irflags])
ylim([0 0.5])
ytikka = 0 : .1 : .6;
set(gca, 'ytick', ytikka)
set(gca, 'yticklabel', sprintf('%2.1f|', ytikka))
title('$\bf \pi_t$', 'interpreter', 'latex')
h = legend('$\bf \pi_t$', '$\bf \pi_{t|t-1}$');
set(h, 'interpreter', 'latex')

subplot(2,3,4)
set(gca, 'fontsize', 16)
hold on
plot(laggy-1, squeeze(hip.IRFy(4,3,laggy) + hip.IRFy(3,3,laggy)), 'linewidth', 2)
plot(laggy-1, squeeze(hiphat.IRFy(4,3,laggy) + hiphat.IRFy(3,3,laggy)), 'r--', 'linewidth', 2)
plot(xlim, [0 0], 'k:', 'linewidth', .5)
set(gca, 'xtick', 0 : irflags)
xlim([0 irflags])
ylim([-.4 .4])
ytikka = -.4 : .2 : .4;
set(gca, 'ytick', ytikka)
set(gca, 'yticklabel', sprintf('%2.1f|', ytikka))
title('$\bf \bar{x}_{t|t} = \gamma_{t|t} + \epsilon_{t|t}$', 'interpreter', 'latex')
h = legend('$\bf \bar{x}_{t|t}$', '$\bf \bar{x}_{t|t-1}$', 'location', 'southeast');
set(h, 'interpreter', 'latex')

subplot(2,3,3)
set(gca, 'fontsize', 16)
hold on
plot(laggy-1, squeeze(hip.IRFy(3,3,laggy) + hip.IRFy(5,3,laggy)), 'linewidth', 2);
plot(laggy-1, squeeze(hiphat.IRFy(3,3,laggy) + hiphat.IRFy(5,3,laggy)), 'r--', 'linewidth', 2);
plot(xlim, [0 0], 'k:', 'linewidth', .5)
set(gca, 'xtick', 0 : irflags)
xlim([0 irflags])
ylim([-.25 1])
ytikka = -.2:.2:1;
set(gca, 'ytick', ytikka)
set(gca, 'yticklabel', sprintf('%2.1f|', ytikka))
title('$\bf s_t$', 'interpreter', 'latex')
h = legend('$\bf s_t$', '$\bf s_{t|t-1}$');
set(h, 'interpreter', 'latex')

subplot(2,3,5)
set(gca, 'fontsize', 16)
hold on
plot(laggy-1, squeeze(hip.IRFy(3,3,laggy)), 'linewidth', 2)
plot(laggy-1, squeeze(hiphat.IRFy(3,3,laggy)), 'r--', 'linewidth', 2)
plot(xlim, [0 0], 'k:', 'linewidth', .5)
set(gca, 'xtick', 0 : irflags)
xlim([0 irflags])
ylim([-.4 .4])
ytikka = -.4 : .2 : .4;
set(gca, 'ytick', ytikka)
set(gca, 'yticklabel', sprintf('%2.1f|', ytikka))
title('$\bf \gamma_{t|t}$', 'interpreter', 'latex')
h = legend('$\bf \gamma_{t|t}$', '$\bf \gamma_{t|t-1}$', 'location', 'southeast');
set(h, 'interpreter', 'latex')

subplot(2,3,6)
set(gca, 'fontsize', 16)
hold on
plot(laggy-1, squeeze(hip.IRFy(4,3,laggy)), 'linewidth', 2)
plot(laggy-1, squeeze(hiphat.IRFy(4,3,laggy)), 'r--', 'linewidth', 2)
plot(xlim, [0 0], 'k:', 'linewidth', .5)
set(gca, 'xtick', 0 : irflags)
xlim([0 irflags])
ylim([-.4 .4])
ytikka  = -.4 : .2 : .4;
set(gca, 'ytick', ytikka)
set(gca, 'yticklabel', sprintf('%2.1f|', ytikka))
title('$\bf \epsilon_{t|t}$', 'interpreter', 'latex')
h = legend('$\bf \epsilon_{t|t}$', '$\bf \epsilon_{t|t-1}$');
set(h, 'interpreter', 'latex')


orient landscape
wrapcf('burgundy202', wrap)

%% wrap up
dockAllFigures
