
%% execute burgundy models

initscript

wrap = []; 
% wrap = 'images';
% note: to store figures as pdf, set wrap to name of target directory
% (use 'pwd' functions or '.' for current directory)
% no figures will be stored if wrap is set to empty

 
%% set parameters
baselinecalibration
rho = .9;
rho_b = 0;
sig_e = 1;
sig_eta = 1;
sig_b   = 1;
brange = [0 : .001 : .01, .02 : .01 : 4];
% brange = .1 : .1 : 4;

%% get no info model: setup model matrices
xNames = {'\tau', '\epsilon'};
yNames = {'\pi'};
uNames = {'x'};
zNames = {'x'}; 
wNames = xNames;

nx = length(xNames);
ny = length(yNames);
nu = length(uNames);
nz = length(zNames);
% Iz = eye(nz);

% Loss
Qxx   = alpha_x * ones(2); 
Qxy   = [0; 0];
Qyy   = 1;
Nx    = -alpha_x * ones(2,1);
Ny    = 0;
R     = alpha_x;

% Welfare
welfare.Qxx    = zeros(2); 
welfare.Qxy    = [0; 0];
welfare.Qyy    = 1;
welfare.Nx     = zeros(2,1);
welfare.Ny     = 0;
welfare.R      = alpha_x;

% x-cons
Axx   = [rho   0
         0     0
        ];
Axy   = zeros(nx,ny);
Bx    = zeros(nx,nu);
D     = diag([sig_eta, sig_e]);

% y-cons
Ayy0  = beta;
Ayy   = 1;
Ayx   = zeros(ny, nx);
By    = -kappa;

% Z-cons
Cx    = zeros(nz, nx);
Cu    = 1;

[hip, pip, Flowtransparency, Glowtransparency, tmp, converged] = ...
   burgundypolicyi(randn(nu,2*nx), randn(ny,nx), beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames);
% note: depending on the randomly chosen initial values, the call to
% burgundypolicyi might fail; in that case, just rerun the code 

if ~converged
   checkthisout
end
LossLowtransparency = hip.EW;

%% Info-Shock model
% setup model matrices
xNames = {'\tau', '\epsilon', 'n'};
yNames = {'\pi'};
uNames = {'x'};
zNames = {'target', 'x'}; 
wNames = xNames;

nx = length(xNames);
ny = length(yNames);
nu = length(uNames);
nz = length(zNames);
nw = length(wNames);

Ix = eye(nx);
% Iz = eye(nz);

% Loss
Qxx   = [alpha_x  alpha_x 0
         alpha_x  alpha_x 0 
         0        0       0]; 
Qxy   = [0; 0; 0];
Qyy   = 1;
Nx    = [-alpha_x;-alpha_x;0];
Ny    = 0;
R     = alpha_x;

% Welfare
welfare.Qxx    = zeros(3); 
welfare.Qxy    = [0; 0; 0];
welfare.Qyy    = 1;
welfare.Nx     = zeros(3,1);
welfare.Ny     = 0;
welfare.R      = alpha_x;

% x-cons
Axx   = [rho   0  0
         0     0  0
         0     0  rho_b
        ];
Axy   = zeros(nx,ny);
Bx    = zeros(nx,nu);
D     = diag([sig_eta, sig_e, sig_b]);

% y-cons
Ayy0  = beta;
Ayy   = 1;
Ayx   = zeros(ny, nx);
By    = -kappa;

% Z-cons
Cx    = [1 0 1; 0 0 0];
Cu    = [0; 1];


[fip, Fbar, Gbar] = markovfullinfopolicyi(randn(nu, nx), randn(ny, nx), beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, xNames, yNames, uNames, wNames);

Fbar %#ok<NOPTS>
Gbar %#ok<NOPTS>
LossBar = fip.EW;

%% loop over transparency
FF          = NaN([size(Fbar,1) 2 * size(Fbar, 2) length(brange)]);
GG          = NaN([size(Gbar,1) 2 * size(Gbar, 2) length(brange)]);
SIGMASTAR   = NaN([size(Fbar, 2) size(Fbar, 2) length(brange)]);
R2          = NaN([1 length(brange)]);
R2prior     = NaN([1 length(brange)]);
tildeR2          = NaN([1 length(brange)]);
tildeR2prior     = NaN([1 length(brange)]);
loss        = NaN([1 length(brange)]);
welfareloss = NaN([1 length(brange)]);
Ktau        = NaN([2 length(brange)]);
InflationSlope = NaN([1 length(brange)]);
Inflation = NaN([1 length(brange)]);

irflags     = 8;
IRF         = NaN([2 3 irflags+1 length(brange)]);


display('Looping over grid of values for sigma_b, please wait ...')

for nb = 1 : length(brange)

   sig_b = brange(nb);

   %% setup model matrices
   xNames = {'\tau', '\epsilon', 'n'};
   yNames = {'\pi'};
   uNames = {'x'};
   zNames = {'target', 'x'};
   wNames = xNames;

   nx = length(xNames);
   ny = length(yNames);
   nu = length(uNames);
   nz = length(zNames);
   nw = length(wNames);

   Ix = eye(nx);
   % Iz = eye(nz);

   % Loss
   Qxx   = [alpha_x  alpha_x 0
      alpha_x  alpha_x 0
      0        0       0];
   Qxy   = [0; 0; 0];
   Qyy   = 1;
   Nx    = [-alpha_x;-alpha_x;0];
   Ny    = 0;
   R     = alpha_x;

   % Welfare
   welfare.Qxx    = zeros(3);
   welfare.Qxy    = [0; 0; 0];
   welfare.Qyy    = 1;
   welfare.Nx     = zeros(3,1);
   welfare.Ny     = 0;
   welfare.R      = alpha_x;

   % x-cons
   Axx   = [rho   0  0
      0     0  0
      0     0  rho_b
      ];
   Axy   = zeros(nx,ny);
   Bx    = zeros(nx,nu);
   D     = diag([sig_eta, sig_e, sig_b]);

   % y-cons
   Ayy0  = beta;
   Ayy   = 1;
   Ayx   = zeros(ny, nx);
   By    = -kappa;

   % Z-cons
   Cx    = [1 0 1; 0 0 0];
   Cu    = [0; 1];


   %% solve burgundy
   %    F0 = randn(nu, nx * 2);
   %    G0 = randn(ny, nx);
   F0 = [Fbar, zeros(nu, nx)];
   G0 = Gbar;

   % [hip, pip, converged, F, G, V, v, EV, K, Sigma, SigmaStar, Ctilde, R2, iter, F0hist] = ...
   [hip, pip, F, G, G0, converged] = ...
      burgundypolicyi(F0, G0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, Cx, Cu, xNames, yNames, uNames, wNames, zNames);

   Ktau(:,nb)   = hip.K(1,:)';
   g0           = G0(1,1);
  
   InflationSlope(nb) = rho * g0 * Ktau(2,nb);
   Inflation(nb) = G(1);
   
   
   EW = socialwelfare(welfare.Qxx, welfare.Qxy, welfare.Qyy, welfare.Nx, welfare.Ny, welfare.R, hip.A, hip.B, F, G, beta);
   
   if ~converged
      newfigure
      multiplot(squeeze(F0hist(:,:,max(1, floor(iter/2)):end))', '.')
      newfigure
      multiplot(squeeze(F0hist(:,:,iter-(10:-1:0)))', '.')
      newfigure
      multihist(squeeze(F0hist(:,:,500:end))')
      error('no convergence')
   end

   %% compute prior signal (via s alone) about tau
   [prior.Sigma, tmp1, tmp2, prior.SigmaStar] = abckalman(Axx, D, Cx(1,:));   
   
   %% store coefficients
   FF(:,:,nb)        = F;
   GG(:,:,nb)        = G;
   SIGMASTAR(:,:,nb) = hip.SigmaStar;
   loss(nb)          = hip.EW;
   welfareloss(nb)   = EW;
   
   tildeR2prior(1,nb) = submat(Sigma2R2(prior.Sigma, prior.SigmaStar), 1, 1);
   R2prior(:,nb)      = tildeR2prior(1,nb) * prior.Sigma(1) / sig_eta^2;
   tildeR2(1,nb)      = submat(Sigma2R2(hip.Sigma, hip.SigmaStar), 1, 1);
   R2(:,nb)           = tildeR2(1,nb) * hip.Sigma(1) / sig_eta^2;
   
   hip = abcdIRF(hip, irflags);
   IRF(:,:,:,nb) = hip.IRFy(1:2,:,:);
   
   
end


%% Summary picture: Coeff, Welfare and Mixing Ratio
figure

subplot(3,2,1)
set(gca, 'fontsize', 16);
hold on
plot(brange, squeeze(FF(1,1,:)), 'linewidth', 2)
ylim([0.4 1])
set(gca, 'ytick', 0 : .2 : 1)
titletexmath('f_{\tau}')

subplot(3,2,2)
set(gca, 'fontsize', 16);
hold on
plot(brange, squeeze(FF(1,2,:)), 'linewidth', 2)
ylim([0.4 1])
set(gca, 'ytick', 0 : .2 : 1)
titletexmath('f_{\epsilon}')

subplot(3,2,3)
set(gca, 'fontsize', 16);
hold on
plot(brange, squeeze(FF(1,3,:))  .* brange', 'b-', 'linewidth', 2);
ylim([-.2 0])
set(gca, 'ytick', -1 : .1: 1)
titletexmath('f_n \cdot \sigma_n')
    

subplot(3,2,4)
set(gca, 'fontsize', 16);
hold on
plot(brange, squeeze(FF(1,4,:)), 'linewidth', 2)
ylim([-.2 0])
set(gca, 'ytick', -1 : .1: 1)
titletexmath('f_{b}')

subplot(3,2,5) 
hold on
set(gca, 'fontsize', 16);
plot(brange, R2prior(1,:), 'r--', 'linewidth', 2)
plot(brange, R2(1,:), 'b-', 'linewidth', 2)
ylim([0.5 1])
titletexmath('Var(\tau_{t|t})/Var(\tau_{t})')
legend('s^t', '(s^t, x^t)', 'location', 'southwest')
xlabel('$\bf \sigma_n$', 'interpreter', 'latex')
   
 
subplot(3,2,6) % Loss
hold on
set(gca, 'fontsize', 16);
plot(brange, loss, 'linewidth', 2)
titletexmath('E(L_t)')
xlabel('$\bf \sigma_n$', 'interpreter', 'latex')


orient landscape
wrapcf('F202summary', wrap)


%% wrap up
display('... done')
dockAllFigures
