%% MARKOV POLICES UNDER FULL INFORMATION

function [abcd, F, G, V, v, history, iter] = markovfullinfoVFI(G0, V0, beta, Qxx, Qxy, Qyy, Nx, Ny, R, Axx, Axy, Bx, D, Ayy0, Ayy, Ayx, By, xNames, yNames, uNames, wNames, Ayx0)

%% options
maxiter     = 1e5;
tolerance   = 1e-10;

%% names
% xHatNames   = cellfun(@(x) sprintf('\\hat{X}:%s', x), xNames, 'uniformoutput', false);

%% prelim
nx = length(xNames);
ny = length(yNames);
nu = length(uNames);
nw = length(wNames); %#ok<NASGU>

Ix = eye(nx);

if nargin < 22 || isempty(Ayx0)
    Ayx0 = zeros(ny, nx);
end

%% check start values
if isempty(G0)
    G0 = zeros(ny, nx);
end
if isempty(V0)
    V0 = zeros(nx);
end

%% fixedpoint loop
converged   = false;
iter        = 0;
history.F   = zeros(nu, nx);
history.V   = zeros(nx);
history     = repmat(history, maxiter, 1);

sqrtbeta    = sqrt(beta);
Q           = [Qxx Qxy Nx; Qxy' Qyy Ny; Nx' Ny' R];

V           = V0;
F           = realmax * ones(nu,nx); % will oly be used to assess convergence after first round

while ~converged && iter < maxiter
  
    % y policy $Y_{t} = G_u U_{t} + G_x X_{t}$$
    Psi0        = Ayy0 * G0 + Ayx0;
    Psi         = Psi0 * Axy - Ayy;
    Gx          = Psi \ (Ayx - Psi0 * Axx);
    Gu          = Psi \ (By - Psi0 * Bx);

   
    % Loss
    HH = [Ix zeros(nx, nu); Gx Gu; zeros(nu, nx) eye(nu)];
    QQ = HH' * Q * HH;
    RR = QQ(nx+1:end, nx+1:end);
    NN = QQ(1:nx, nx+1:end);

    % Transition
    AA    = Axx + Axy * Gx;
    BB    = Bx + Axy * Gu;

    % FOC
    VV    = V * beta;
    Fnew  = -(RR + BB' * VV * BB) \ (NN' + BB' * VV * AA);

    % Update V (at old G0, but with Fnew)
    % Transition
    A0    = AA + BB * Fnew;
    
    % Closed Loop: Loss
    H0      = [Ix; Gx + Gu * Fnew; Fnew]; 
    Q0      = H0' * Q * H0;
    Vnew    = Q0 + beta * A0' * V * A0;
    
    % Update G
    G0new  = Gx + Gu * Fnew;
    
    % check convergence
    dF          = F  - Fnew;
    dG0         = G0 - G0new;
    dV          = V  - Vnew;
    converged   = max(abs([dF(:); dG0(:); dV(:)])) < tolerance;
    
    % prep next round
    iter = iter + 1;
    F   = Fnew;
    G0  = G0new;
    V   = Vnew;
    history(iter).F	= F;
    history(iter).V	= V;

    
end
% progressbar(1)
history = history(1:iter);

if ~converged
    
    dispcalc('F')
    error('reached maximum loops but without convergence: current accuracy after %d iterations is %8.4e', iter, max(abs(dF(:))))
    
else % closed loop stuff
    
    % Closed Loop: Transition

    G   = G0;
    A0  = AA + BB * F;
    
    % Closed Loop: Loss
    H0 = [Ix; G; F];
    Q0 = H0' * Q * H0;
    
    % Closed Loop: Value
    V = dlyapdoubling(sqrtbeta * A0', Q0);
    checkdiff(V, Vnew, tolerance * 10);
    
    v = trace(V * (D * D')) * beta / (1 - beta);
    
end

% state space
abcd.A   = A0;
abcd.B   = D;
abcd.Cx  = [F; G; Ix];
abcd     = abcddims(abcd);

abcd.Xnames = xNames;
abcd.Ynames = cat(2, uNames, yNames, xNames);
abcd.Wnames = wNames;


if all(abs(eig(abcd.A)) < 1)
    abcd.Q      = Q0;
    abcd        = abcdwelfare(abcd);
end
