function h = plotIRFs(IRF, TwoSideFlag, RSPnames, IMPnames, RSPndx, IMPndx, IRFother, tickSize, sameColLims, sameRowLims)
% function plotIRFs(IRF, TwoSideFlag, RSPnames, IMPnames, RSPndx, IMPndx, IRFother, tickSize, sameColLims, sameRowLims)

%   Coded by  Elmar Mertens, em@elmarmertens.com

error(nargchk(1,10,nargin))

[R, I, MM] = size(IRF);

if nargin < 2 || isempty(TwoSideFlag)
   TwoSideFlag = false;
end

if nargin < 3
   RSPnames = [];
end

if nargin < 4
   IMPnames = [];
end

if nargin < 5 || isempty(RSPndx)
   RSPndx = 1 : R;
else
   RSPndx = RSPndx(:)';
   R      = length(RSPndx);
end

if nargin < 6 || isempty(IMPndx)
   IMPndx = 1 : I;
else
   IMPndx = IMPndx(:)';
   I      = length(IMPndx);
end

if nargin < 7
   IRFother = [];
end

if TwoSideFlag
   M = (MM - 1) / 2;
   timeAxis = -M : M;
else
   M = MM - 1;
   timeAxis = (0 : M)';
end

if nargin < 8 || isempty(tickSize)
   if M <= 4
      tickSize = 1;
   else
      %       tickSize = min(M, floor(MM / 20 / I));
      tickSize = 4;
   end
end

if nargin < 9
   sameColLims = false;
elseif ~isscalar(sameColLims)
   minyc = repmat(sameColLims(1), length(RSPndx),1);
   maxyc = repmat(sameColLims(2), length(RSPndx),1);
   sameColLims = true;
end

if nargin < 10
   sameRowLims = false;
elseif ~isscalar(sameRowLims)
   minyr = repmat(sameRowLims(1), length(IMPndx),1);
   maxyr = repmat(sameRowLims(2), length(IMPndx),1);
   sameRowLims = true;
end

% for same row lims
if sameRowLims && ~exist('maxyr', 'var') % && ~exist('minyr', 'var')
   [minyr, maxyr] = deal(zeros(length(RSPndx), 1));
   for rndx = 1 : R
      r = RSPndx(rndx);
      minyr(rndx) = min(min(IRF(r,:,:)));
      maxyr(rndx) = max(max(IRF(r,:,:)));
      if ~isempty(IRFother)
         jockey   = IRFother(r, :, :,:);
         minyr(rndx) = min(minyr(rndx), min(jockey(:)));
         maxyr(rndx) = max(maxyr(rndx), max(jockey(:)));
      end
   end
   minyr(minyr <  0)   =  1.1 * minyr(minyr <  0);
   minyr(minyr >  0)   =  0.9 * minyr(minyr >  0);
   
   maxyr(maxyr <  0)   =  0.9 * maxyr(maxyr <  0);
   maxyr(maxyr >  0)   =  1.1 * maxyr(maxyr >  0);
   
   minyr = chop(minyr, 2);
   maxyr = chop(maxyr, 2);
end

% for same col lims
if sameColLims && ~exist('maxyc', 'var') % && ~exist('minyc', 'var')
   [minyc, maxyc] = deal(zeros(length(RSPndx), 1));
   for cndx = 1 : I
      c = IMPndx(cndx);
      minyc(cndx) = min(min(IRF(:,c,:)));
      maxyc(cndx) = max(max(IRF(:,c,:)));
      if ~isempty(IRFother)
         jockey   = IRFother(:, c, :,:);
         minyc(cndx) = min(minyc(cndx), min(jockey(:)));
         maxyc(cndx) = max(maxyc(cndx), max(jockey(:)));
      end
   end
   minyc(minyc <  0)   =  1.1 * minyc(minyc <  0);
   minyc(minyc >  0)   =  0.9 * minyc(minyc >  0);
   
   maxyc(maxyc <  0)   =  0.9 * maxyc(maxyc <  0);
   maxyc(maxyc >  0)   =  1.1 * maxyc(maxyc >  0);

   minyc = chop(minyc, 2);
   maxyc = chop(maxyc, 2);
end

if sameColLims && sameRowLims %% samelims across rows and columns
   minyc(:) = min([minyc(:); minyr(:)]);
   minyr    = minyc;
   maxyc(:) = max([maxyc(:); maxyr(:)]);
   maxyr    = maxyc;
end

% clf reset
h = zeros(R,I);
for rndx = 1 : R
   r = RSPndx(rndx);

   for indx = 1 : I
      i = IMPndx(indx);
      
      h(rndx, indx) = subplot(R, I, (rndx - 1) * I + indx);
      %       getfontsize % set(gca, 'fontsize', 16)
      hold on


      plot(timeAxis, squeeze(IRF(r, i, :)), 'b-', 'LineWidth', 2); %, 'Marker', 'o', 'MarkerSize', 3);
      if ~isempty(IRFother)
         jack = min(length(timeAxis), size(IRFother, 3));
         plotindy(timeAxis(1:jack), squeeze(IRFother(r, i, 1:jack, :)), {'--', '-.', ':',':'}, Colors4Plots(1 + (1:size(IRFother, 3))), {'none', 'none', 'p', 'x'}, 2);
      end

      if indx == 1 && ~isempty(RSPnames)
         ylabel(RSPnames(r));
      end
      if rndx == 1 && ~isempty(IMPnames)
         title(IMPnames(i));
      end

      if sameColLims
         if minyc(indx) == maxyc(indx) % if TS is a constant
            minyc(indx) = minyc(indx) - 1;
            maxyc(indx) = maxyc(indx) + 1;
         end
         ylim([minyc(indx), maxyc(indx)])
      end
      if sameRowLims
         if minyr(rndx) == maxyr(rndx) % if TS is a constant
            minyr(rndx) = minyr(rndx) - 1;
            maxyr(rndx) = maxyr(rndx) + 1;
         end
         ylim([minyr(rndx), maxyr(rndx)])
      end

      % draw origin
      hold on
      plot(timeAxis([1 end]), [0 0], 'k:')

      if TwoSideFlag
         if sameLimFlag
            joe = [miny, maxy];
         else
            joe = get(gca,'Ylim');
         end
         plot([0 0], joe, 'k:')
      end

      %       if TwoSideFlag
      %          set(gca,'XTick', timeAxis(1:tickSize:end))
      %       else
      %          set(gca,'XTick', timeAxis(1:tickSize:end))
      %       end
      set(gca,'XTick', timeAxis(1:tickSize:end))
      xlim(timeAxis([1 end]))
      hold off
      %grid on

   end
end
