function h = plotindy(x, y, linestyles, colors, markers, linewidths)
% function h = plotindy(x, y, linestyles, colors, markers, linewidths)

%   Coded by  Elmar Mertens, em@elmarmertens.com

error(nargchk(2,6,nargin))

[T, N] = size(y);
if isempty(x)
   x = 1 : T;
elseif isvector(x)
   x = x(:);
end

[Tx, Nx] = size(x);
if ~isequal(Tx, T)
   error('x and y need to have same number of rows')
end

if Nx ~= 1 && Nx ~= N
   error('x and y need to have same number of columns (or x is vector)')
end

if Nx == 1
   x = repmat(x, 1, N);
end

%% init attributes

if nargin < 3 || isempty(linestyles)
   linestyles = {'-', '--', '-.', ':'};
end

if nargin < 4 || isempty(colors)
   colors = Colors4Plots;
end

if nargin < 5 || isempty(markers)
   markers = repmat({'none'}, N, 1);
end

if nargin < 6 || isempty(linewidths)
   linewidths = repmat({2}, N, 1);
end

%% make sure that there are enough attributes per column
if ~iscell(linestyles)
   linestyles = {linestyles};
end
if ~iscell(colors)
   colors = {colors};
end
if ~iscell(markers)
   markers = {markers};
end
if ~iscell(linewidths)
   linewidths = {linewidths};
end
if length(linestyles) < N
   linestyles = repmat(linestyles, 1, ceil(N / length(linestyles)));
end
if length(colors) < N
   colors = repmat(colors, 1, ceil(N / length(colors)));
end
if length(markers) < N
   markers = repmat(markers, 1, ceil(N / length(markers)));
end
if length(linewidths) < N
   linewidths = repmat(linewidths, 1, ceil(N / length(linewidths)));
end


%% start plotting
h = NaN(N, 1);
hold on
for n = 1 : N
   h(n) = plot(x(:,n), y(:,n), 'color', colors{n}, 'linestyle', linestyles{n}, 'linewidth', linewidths{n}, 'marker', markers{n});
end
