%% output targets
% $$L_t = \pi_t^2 + \alpha_x(x_t-g_t-\varepsilon_t)^2$$
%
% $$\pi_t = \beta \pi_{t+1|t} + \kappa x_t$$
%
% $$Z_t=x_t$$

modelname = strrep(mfilename, 'setup', '');
setpref('LQmodels', 'setupfile', mfilename);


eval(string4ini('rho', .9));
eval(string4ini('sig_gamma', 1));
eval(string4ini('sig_eps', 1));

%% setup model matrices
xNames = {'\gamma', '\epsilon', 'E\gamma'};
yNames = {'\pi'};
uNames = {'x'};
zNames = {'x', 'E\gamma'}; 
wNames = xNames(1:2);

nx = length(xNames);
ny = length(yNames);
nu = length(uNames);
nz = length(zNames);
nw = length(wNames);

Ix = eye(nx);
% Iz = eye(nz);

% Loss
Qxx   = zeros(nx);
Qxx(1:2,1:2)   = alpha_x * ones(2); 
Qxy   = [0; 0; 0];
Qyy   = alpha_p;
Nx    = [-alpha_x * ones(2,1); 0];
Ny    = 0;
R     = alpha_x;

% Welfare
welfare.Qxx    = zeros(3); 
welfare.Qxy    = [0; 0; 0];
welfare.Qyy    = 1;
welfare.Nx     = zeros(3,1);
welfare.Ny     = 0;
welfare.R      = alpha_x;

% x-cons
Axx   = [rho   0   0
         0     0   0
         rho   0   0
        ];
Axy   = zeros(nx,ny);
Bx    = zeros(nx,nu);
D     = diag([sig_gamma, sig_eps, 0]);
D     = D(:,1:2);

% y-cons
Ayy0  = beta;
Ayx0  = zeros(ny, nx);
Ayy   = 1;
Ayx   = zeros(ny, nx);
By    = -kappa;

% Z-cons
Cx    = [0 0 0; 0 0 1];
Cu    = [1; 0];

%% dimension checks
dimchk(Qxx, nx, nx);
dimchk(Qxy, nx, ny);
dimchk(Qyy, ny, ny);
dimchk(Nx, nx, nu);
dimchk(Ny, ny, nu);
dimchk(R, nu, nu);
dimchk(Axx, nx, nx);
dimchk(Axy, nx, ny);
dimchk(Bx, nx, nu);
dimchk(D, nx, nw);
dimchk(Ayy0, ny, ny);
dimchk(Ayy, ny, ny);
dimchk(Ayx, ny, nx);
dimchk(By, ny, nu);
dimchk(Cx, nz, nx);
dimchk(Cu, nz, nu);


%% check posdef loss
if any(eig([Qxx Qxy Nx; Qxy' Qyy Ny; Nx' Ny' R]) + 1e-10 < 0)
    error('Loss function is not positive definite. The eigenvalues are \n %s', sprintf('\t%20.12f\n', eig([Qxx Qxy Nx; Qxy' Qyy Ny; Nx' Ny' R]))) %#ok<SPERR>
end
