function [EW, w] = socialwelfare(Qxx, Qxy, Qyy, Nx, Ny, R, A0, D0, F, G, beta, hiddeninfo)
% function [EW, w] = socialwelfare(Qxx, Qxy, Qyy, Nx, Ny, R, A0, D0, F, G, beta)
% computes welfare for given transition and decision rules
% hiddeninfo = true: uses hidden info model with states [X, X_ttm1]

if nargin < 12
   hiddeninfo = true;
end

% closed loop objective
if hiddeninfo
   HH    = [eye(size(Qxx)) zeros(size(Qxx)); G; F];
else
   HH    = [eye(size(Qxx)); G; F];
end
Q0    = HH' * [Qxx Qxy Nx; Qxy' Qyy Ny; Nx' Ny' R] * HH;

% closed loop: Value
W = dlyapdoubling(sqrt(beta) * A0', Q0);
w = trace(W * (D0 * D0')) * beta / (1 - beta);

Exx   = dlyapdoubling(A0, D0 * D0');
EW    = w + trace(W * Exx);
